# Rule

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**icmp_type** | **str** |  | [optional] 
**id** | **str** |  | [optional] 
**ip_range_cidr** | **str** |  | [optional] 
**ports** | **str** |  | [optional] 
**protocol** | [**Protocol**](Protocol.md) |  | [optional] 
**rule_type** | [**RuleType**](RuleType.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


